@@ -30,13 +30,6 @@ class ApplicationAccessToken:
             self.token = data['access_token']
 
 
-class User:
-    def __init__(self, username, userid, password=None):
-        self.username = username
-        self.password = password
-        self.userid = userid
-
-
 class ApplicationTeam:
     def __init__(self, tenant_id, client_id, client_secret, **kwargs):
         self.tenant_id = tenant_id
@@ -103,14 +96,12 @@ class ApplicationTeam:
         response = requests.post(
             'https://graph.microsoft.com/v1.0/users', json=data,
             headers=headers)
-        return_values = response.json()
-        if 'error' in return_values.keys():
-            self.errors = return_values['error']['message']
+        json = response.json()
+        if 'error' in json.keys():
+            self.errors = json['error']['message']
             return False
         else:
-            self.user = User(
-                userPrincipalName, userid=return_values['id'],
-                password=password)
+            self.user = json
             return True
 
 
