@@ -116,3 +116,17 @@ class Zoom:
         else:
             self.meeting = json
             return True
+
+    def delete_meeting(self, meeting_id):
+        url = 'https://api.zoom.us/v2/meetings/{}'
+        url = url.format(meeting_id)
+
+        headers = {'Authorization': 'Bearer {}'.format(self.access_token)}
+
+        response = requests.delete(url=url, headers=headers)
+        json = response.json()
+        if 'code' in json.keys():
+            self.errors = {'code': 0, 'message': json['message']}
+            return False
+        else:
+            return True
